Extractor
---------

Problematic
^^^^^^^^^^^

How can we extract data from other data?

Documentation
^^^^^^^^^^^^^

.. automodule:: PyFunceble.extractor
   :members:
   :private-members:

:code:`ExtractorBase()`
"""""""""""""""""""""""

.. autoclass:: PyFunceble.extractor.base.ExtractorBase
    :members:
    :private-members:

:code:`ExpirationDate()`
""""""""""""""""""""""""

.. autoclass:: PyFunceble.extractor.expiration_date.ExpirationDate
    :members:
    :private-members:

